pub struct CartridgeMemory {
pub prg_ram: Vec<u8>,
pub prg_rom: Vec<u8>,
pub chr_ram: Vec<u8>,
pub chr_rom: Vec<u8>,
pub nametable_arrangement: NametableArrangement,
}Expand description
Contains all memory in the cartridge that isn’t mapper-specific.
Contains PRG/CHR ROM/RAM. Does not contain any latches, banks, or dividers used by mappers.
Fields
prg_ram: Vec<u8>Program RAM (PRG RAM) of the cartridge
prg_rom: Vec<u8>Program ROM (PRG ROM) of the cartridge
chr_ram: Vec<u8>Character RAM (CHR RAM) of the cartridge
chr_rom: Vec<u8>Character ROM (CHR ROM) of the cartridge
nametable_arrangement: NametableArrangementNametable arrangement of the cartridge, read when parsing the file. May be changed by the mapper, use Mapper::nametable_arrangement to get the current nametable arrangement being used
Implementations
Sourceimpl CartridgeMemory
impl CartridgeMemory
Sourcepub fn read_chr(&self, addr: usize) -> u8
pub fn read_chr(&self, addr: usize) -> u8
Read a byte from CHR ROM or (if CHR ROM is empty) CHR RAM.
This is really a convience function, since most cartridges either are all CHR ROM or CHR RAM. So this could be interpreted as just “Read CHR from whatever format the cartridge using”
Sourcepub fn read_prg_ram(&self, addr: usize) -> u8
pub fn read_prg_ram(&self, addr: usize) -> u8
Read a byte from PRG RAM
Read from the PRG RAM on the cartridge, wrapping around the end if addr is too large
Sourcepub fn write_prg_ram(&mut self, addr: usize, value: u8)
pub fn write_prg_ram(&mut self, addr: usize, value: u8)
Write a byte to PRG RAM
Write to PRG RAM, wrapping around the end if addr is too large
Sourcepub fn read_prg_rom(&self, addr: usize) -> u8
pub fn read_prg_rom(&self, addr: usize) -> u8
Read a byte from PRG ROM
Read from PRG ROM, wrapping around the end if addr is too large